/****************************************************************
**
** Implementation of CIGLWIdget class
**
****************************************************************/


#include "CIGLWidget.h"

#include "CIMoebius.h"
CIMoebius pp;
CIGLWidget::CIGLWidget( QWidget *parent, const char *name ): QGLWidget(parent, name)
{
    SideNum=3;
		Twist=1;
		lx=ly=-1;
}
	
void CIGLWidget::initializeGL()
{   
  // Set up the rendering context, define display lists etc.:
  glClearColor( 0.0, 1.0, 1.0, 0.0 );
	CIMoebius::myShape s;
	s.BuildNGon(SideNum,1);
	pp.GenerateMoebiusRing(s,36,3,Twist*360/SideNum);
	float spec[4]={.4,.4,.4,1};
	float shin = 1;
	glMaterialfv(GL_FRONT_AND_BACK,GL_SPECULAR , spec);
	glMaterialf(GL_FRONT_AND_BACK,GL_SHININESS , shin);
	
	glColorMaterial(GL_FRONT_AND_BACK,GL_AMBIENT_AND_DIFFUSE );
	glEnable(GL_COLOR_MATERIAL);
	
	// Abilita il la possibilita' di cambiare il alcune componenti colore del 
	// materiale tramite un semplice glcolor, anzich fare glMaterial(...)
	glColorMaterial(GL_FRONT_AND_BACK,GL_AMBIENT_AND_DIFFUSE);
	glEnable(GL_COLOR_MATERIAL);

	// Abilita il calcolo dell'illuminazione
	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);

	// anche le normali attraversano la pipeline, quindi devono essere  
	// rinormalizzate, prima del calcolo dell'illuminazione, altrimenti 
	// il calcolo dell'illuminazione viene sbagliato.
	glEnable(GL_NORMALIZE); 
	
	// Abilita il test sullo zbuffer e quindi l'eliminazione delle 
	// superfici nascoste
	glEnable(GL_DEPTH_TEST); 	

	// Disabilita lo shading di gouraud per le facce dei poligoni disegnati
	glShadeModel(GL_SMOOTH);
}

void CIGLWidget::resizeGL( int w, int h )
{
  // setup viewport, projection etc.:
	glMatrixMode (GL_PROJECTION);   
	glLoadIdentity ();
	float ratio=(float)w/(float)h;
  gluPerspective(45,ratio,3,20);
	glViewport (0, 0, (GLsizei) w, (GLsizei) h); 
	glMatrixMode (GL_MODELVIEW);
}

void CIGLWidget::paintGL()
{
	glMatrixMode (GL_MODELVIEW);
	glClear(GL_COLOR_BUFFER_BIT |GL_DEPTH_BUFFER_BIT  );
	glLoadIdentity();
	gluLookAt(2,5,12,0,0,0,0,1,0);
  glColor3f(1,.4,.4);
	pp.m.Draw();	
	QString tmp;
	renderText(lx,ly,tmp.sprintf("Mouse pressed on %i %i",lx,ly));
}

void CIGLWidget::mousePressEvent(QMouseEvent*e)
{
	lx=e->x();
	ly=e->y();
	update();
}
